@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'riddle/client/filter'
 require 'riddle/client/message'
 require 'riddle/client/response'
@@ -92,14 +94,15 @@ module Riddle
     }
 
     AttributeTypes = {
-      :integer    => 1, # SPH_ATTR_INTEGER
-      :timestamp  => 2, # SPH_ATTR_TIMESTAMP
-      :ordinal    => 3, # SPH_ATTR_ORDINAL
-      :bool       => 4, # SPH_ATTR_BOOL
-      :float      => 5, # SPH_ATTR_FLOAT
-      :bigint     => 6, # SPH_ATTR_BIGINT
-      :string     => 7, # SPH_ATTR_STRING
-      :multi      => 0x40000000 # SPH_ATTR_MULTI
+      :integer      => 1, # SPH_ATTR_INTEGER
+      :timestamp    => 2, # SPH_ATTR_TIMESTAMP
+      :ordinal      => 3, # SPH_ATTR_ORDINAL
+      :bool         => 4, # SPH_ATTR_BOOL
+      :float        => 5, # SPH_ATTR_FLOAT
+      :bigint       => 6, # SPH_ATTR_BIGINT
+      :string       => 7, # SPH_ATTR_STRING
+      :group_concat => 10,
+      :multi        => 0x40000000 # SPH_ATTR_MULTI
     }
 
     GroupFunctions = {
@@ -625,7 +628,8 @@ module Riddle
     # Send a collection of messages, for a command type (eg, search, excerpts,
     # update), to the Sphinx daemon.
     def request(command, messages)
-      response = ""
+      response = StringIO.new String.new(""), "w"
+      response.set_encoding "ASCII-8BIT"
       status   = -1
       version  = 0
       length   = 0
@@ -660,6 +664,8 @@ module Riddle
         end
       end
 
+      response = response.string
+
       if response.empty? || response.length != length
         raise ResponseError, "No response from searchd (status: #{status}, version: #{version})"
       end
@@ -830,13 +836,14 @@ module Riddle
     end
 
     AttributeHandlers = {
-      AttributeTypes[:integer]   => :next_int,
-      AttributeTypes[:timestamp] => :next_int,
-      AttributeTypes[:ordinal]   => :next_int,
-      AttributeTypes[:bool]      => :next_int,
-      AttributeTypes[:float]     => :next_float,
-      AttributeTypes[:bigint]    => :next_64bit_int,
-      AttributeTypes[:string]    => :next,
+      AttributeTypes[:integer]      => :next_int,
+      AttributeTypes[:timestamp]    => :next_int,
+      AttributeTypes[:ordinal]      => :next_int,
+      AttributeTypes[:bool]         => :next_int,
+      AttributeTypes[:float]        => :next_float,
+      AttributeTypes[:bigint]       => :next_64bit_int,
+      AttributeTypes[:string]       => :next,
+      AttributeTypes[:group_concat] => :next,
       AttributeTypes[:multi] + AttributeTypes[:integer] => :next_int_array
     }
 
