@@ -15,7 +15,7 @@ module Riddle
           :html_index_attrs, :html_remove_elements, :preopen, :ondisk_dict,
           :inplace_enable, :inplace_hit_gap, :inplace_docinfo_gap,
           :inplace_reloc_factor, :inplace_write_factor, :index_exact_words,
-          :overshort_step, :stopwords_step, :hitless_words, :ha_strategy,
+          :overshort_step, :stopword_step, :hitless_words, :ha_strategy,
           :bigram_freq_words, :bigram_index, :index_field_lengths,
           :regexp_filter, :stopwords_unstemmed, :global_idf, :rlp_context,
           :ondisk_attrs
@@ -33,7 +33,7 @@ module Riddle
         :html_remove_element_tags, :preopen, :ondisk_dict, :inplace_enable,
         :inplace_hit_gap, :inplace_docinfo_gap, :inplace_reloc_factor,
         :inplace_write_factor, :index_exact_words, :overshort_step,
-        :stopwords_step, :hitless_words, :ha_strategy, :bigram_freq_words,
+        :stopword_step, :hitless_words, :ha_strategy, :bigram_freq_words,
         :bigram_index, :index_field_lengths, :regexp_filter,
         :stopwords_unstemmed, :global_idf, :rlp_context, :ondisk_attrs
 
