@@ -18,7 +18,7 @@ module Riddle
     end
 
     def sphinx_version
-      `#{indexer} 2>&1`[/Sphinx (\d+\.\d+(\.\d+|(?:-dev|(\-id64)?\-beta)))/, 1]
+      `#{indexer} 2>&1`[/(Sphinx|Manticore) (\d+\.\d+(\.\d+|(?:-dev|(\-id64)?\-beta)))/, 2]
     rescue
       nil
     end
@@ -74,7 +74,7 @@ module Riddle
     end
 
     def pid
-      if File.exists?(configuration.searchd.pid_file)
+      if File.exist?(configuration.searchd.pid_file)
         File.read(configuration.searchd.pid_file)[/\d+/]
       else
         nil
